@@ -6,15 +6,15 @@ import (
 	"os"
 	"testing"
 
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/config"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"github.com/tfsec/tfsec/internal/app/tfsec/config"
 )
 
 func TestExcludesElementsFromYAML(t *testing.T) {
 	content := `
 severity_overrides:
-  AWS018: INFO
+  AWS018: LOW
 
 exclude:
   - DP001
@@ -28,7 +28,7 @@ exclude:
 func TestExcludesElementsFromYML(t *testing.T) {
 	content := `
 severity_overrides:
-  AWS018: INFO
+  AWS018: LOW
 
 exclude:
   - DP001
@@ -42,7 +42,7 @@ exclude:
 func TestExcludesElementsFromJSON(t *testing.T) {
 	content := `{
   "severity_overrides": {
-    "AWS018": "INFO"
+    "AWS018": "LOW"
   },
   "exclude": [
     "DP001"
@@ -55,6 +55,23 @@ func TestExcludesElementsFromJSON(t *testing.T) {
 	assert.Contains(t, c.ExcludedChecks, "DP001")
 }
 
+func TestWarningIsRewrittenAsMedium(t *testing.T) {
+	content := `{
+  "severity_overrides": {
+    "AWS018": "WARNING"
+  },
+  "exclude": [
+    "DP001"
+  ]
+}
+`
+	c := load(t, "config.json", content)
+
+	assert.Contains(t, c.SeverityOverrides, "AWS018")
+	sev := c.SeverityOverrides["AWS018"]
+	assert.Equal(t, "MEDIUM", sev)
+}
+
 func load(t *testing.T, filename, content string) *config.Config {
 	dir, err := ioutil.TempDir("", "")
 	require.NoError(t, err)
