@@ -25,3 +25,9 @@ func OptionWithWorkspaceName(workspaceName string) Option {
 		p.workspaceName = workspaceName
 	}
 }
+
+func OptionSkipDownloaded() Option {
+	return func(p *Parser) {
+		p.skipDownloaded = true
+	}
+}
\ No newline at end of file
